"""Script for running tsunami inundation scenario for Dampier, WA, Australia.

Source data such as elevation and boundary data is assumed to be available in
directories specified by project.py
The output sww file is stored in project.output_time_dir 

The scenario is defined by a triangular mesh created from project.polygon,
the elevation data and a simulated submarine landslide.

Ole Nielsen and Duncan Gray, GA - 2005 and Jane Sexton, Nick Bartzis, GA - 2006
"""

#------------------------------------------------------------------------------
# Import necessary modules
#------------------------------------------------------------------------------

# Standard modules
from os import sep
from os.path import dirname, basename
from os import mkdir, access, F_OK
from shutil import copy
import time
import sys

# Related major packages
from anuga.shallow_water import Domain
#from anuga.shallow_water import Dirichlet_boundary
#from anuga.shallow_water import File_boundary
#from anuga.shallow_water import Reflective_boundary
from anuga.shallow_water.data_manager import convert_dem_from_ascii2netcdf, dem2pts
from anuga.pmesh.mesh_interface import create_mesh_from_regions
from anuga.geospatial_data.geospatial_data import *
from anuga.abstract_2d_finite_volumes.util import start_screen_catcher, copy_code_files

# Application specific imports
import project   # Definition of file names and polygons

#------------------------------------------------------------------------------
# Copy scripts to time stamped output directory and capture screen
# output to file
#------------------------------------------------------------------------------

copy_code_files(project.output_build_time_dir,__file__, 
               dirname(project.__file__)+sep+ project.__name__+'.py' )

start_screen_catcher(project.output_build_time_dir)

print 'USER:    ', project.user

#-------------------------------------------------------------------------------
# Preparation of topographic data
#
# Convert ASC 2 DEM 2 PTS using source data and store result in source data
# Do for coarse and fine data
# Fine pts file to be clipped to area of interest
#-------------------------------------------------------------------------------
print"project.bounding_polygon",project.bounding_polygon
print"project.combined_dir_name",project.combined_dir_name

# topography directory filenames
onshore_in_dir_name = project.onshore_in_dir_name
coast_in_dir_name = project.coast_in_dir_name
island_in_dir_name = project.island_in_dir_name
island_in_dir_name1 = project.island_in_dir_name1
island_in_dir_name2 = project.island_in_dir_name2
island_in_dir_name3 = project.island_in_dir_name3
offshore_in_dir_name = project.offshore_in_dir_name

onshore_dir_name = project.onshore_dir_name
coast_dir_name = project.coast_dir_name
island_dir_name = project.island_dir_name
island_dir_name1 = project.island_dir_name1
island_dir_name2 = project.island_dir_name2
island_dir_name3 = project.island_dir_name3
offshore_dir_name = project.offshore_dir_name

# creates DEM from asc data
convert_dem_from_ascii2netcdf(onshore_in_dir_name, basename_out=onshore_dir_name, use_cache=True, verbose=True)
convert_dem_from_ascii2netcdf(island_in_dir_name, basename_out=island_dir_name, use_cache=True, verbose=True)
convert_dem_from_ascii2netcdf(island_in_dir_name1, basename_out=island_dir_name1, use_cache=True, verbose=True)
convert_dem_from_ascii2netcdf(island_in_dir_name2, basename_out=island_dir_name2, use_cache=True, verbose=True)
convert_dem_from_ascii2netcdf(island_in_dir_name3, basename_out=island_dir_name3, use_cache=True, verbose=True)

#creates pts file for onshore DEM
dem2pts(onshore_dir_name,
#        easting_min=project.eastingmin,
#        easting_max=project.eastingmax,
#        northing_min=project.northingmin,
#        northing_max= project.northingmax,
        use_cache=True, 
        verbose=True)

#creates pts file for island DEM
dem2pts(island_dir_name, use_cache=True, verbose=True)
dem2pts(island_dir_name1, use_cache=True, verbose=True)
dem2pts(island_dir_name2, use_cache=True, verbose=True)
dem2pts(island_dir_name3, use_cache=True, verbose=True)

print'create Geospatial data objects from topographies'
G1 = Geospatial_data(file_name = onshore_dir_name + '.pts')
G2 = Geospatial_data(file_name = coast_in_dir_name + '.xya')
G3 = Geospatial_data(file_name = island_dir_name + '.pts')
G4 = Geospatial_data(file_name = island_dir_name1 + '.pts')
G5 = Geospatial_data(file_name = island_dir_name2 + '.pts')
G6 = Geospatial_data(file_name = island_dir_name3 + '.pts')
G_off = Geospatial_data(file_name = offshore_in_dir_name + '.xya')

print'add all geospatial objects'
G = G1 + G2 + G3 + G4 + G5 + G6 + G_off 

print'clip combined geospatial object by bounding polygon'
G_clipped = G.clip(project.bounding_polygon)
#FIXME: add a clip function to pts
#print'shape of clipped data', G_clipped.get_data_points().shape

print'export combined DEM file'
if access(project.topographies_dir,F_OK) == 0:
    mkdir (project.topographies_dir)
#G_clipped.export_points_file(project.combined_dir_name + '.pts')
G_clipped.export_points_file(project.combined_dir_name + '.xya')


'''
#-------------------------------------------------------------------------
# Convert URS to SWW file for boundary conditions 
#-------------------------------------------------------------------------
print 'starting to create boundary conditions'
boundaries_in_dir_name = project.boundaries_in_dir_name

from anuga.shallow_water.data_manager import urs2sww

print 'minlat=project.north_boundary, maxlat=project.south_boundary',project.north_boundary, project.south_boundary
print 'minlon= project.west_boundary, maxlon=project.east_boundary',project.west_boundary, project.east_boundary

#import sys; sys.exit()

#if access(project.boundaries_dir,F_OK) == 0:
#    mkdir (project.boundaries_dir)

from caching import cache
cache(urs2sww,
      (boundaries_in_dir_name,
       project.boundaries_dir_name1), 
      {'verbose': True,
       'minlat': project.south_boundary,
       'maxlat': project.north_boundary,
       'minlon': project.west_boundary,
       'maxlon': project.east_boundary,
#       'minlat': project.south,
#       'maxlat': project.north,
#       'minlon': project.west,
#       'maxlon': project.east,
       'mint': 0, 'maxt': 40000,
#       'origin': domain.geo_reference.get_origin(),
       'mean_stage': project.tide,
#       'zscale': 1,                 #Enhance tsunami
       'fail_on_NaN': False},
       verbose = True,
       )
#       dependencies = source_dir + project.boundary_basename + '.sww')

'''







